Learn R Programming

rolap (version 2.5.1)

add_surrogate_key.dimension_table: Add the surrogate key from a dimension table to the instances table.

Description

Add the surrogate key from a dimension table to the instances table.

Usage

# S3 method for dimension_table
add_surrogate_key(dimension_table, instances)

Value

A tibble.

Arguments

dimension_table

A dimension_table object.

instances

A tibble, the instances table.