Learn R Programming

rolap (version 2.5.1)

as_geolayer: Get a geolayer object

Description

From a star_database with at least one geoattribute, we obtain a geolayer object that allows us to select the data to obtain a vector layer with geographic information.

Usage

as_geolayer(db, dimension, attribute, geometry, include_nrow_agg)

# S3 method for star_database as_geolayer( db, dimension = NULL, attribute = NULL, geometry = NULL, include_nrow_agg = FALSE )

Value

A geolayer object.

Arguments

db

An star_database object.

dimension

A string, dimension name.

attribute

A vector, attribute names.

geometry

A string, geometry name.

include_nrow_agg

A boolean, include default measure.

Details

If only one geographic attribute is defined, it is not necessary to indicate the dimension or the attribute. By default, polygon geometry is considered.

See Also

Other query functions: as_GeoPackage(), filter_dimension(), get_layer(), get_variable_description(), get_variables(), run_query(), select_dimension(), select_fact(), set_layer(), set_variables(), star_query()

Examples

Run this code

gl_polygon <- mrs_db_geo |>
  as_geolayer()

gl_point <- mrs_db_geo |>
  as_geolayer(geometry = "point")

Run the code above in your browser using DataLab