Learn R Programming

rolap (version 2.5.1)

get_transformation_file: Get transformation function file

Description

From the planned update, it obtains the function with the source code of the transformations performed on the original data in file format.

Usage

get_transformation_file(sdbu, file)

# S3 method for star_database_update get_transformation_file(sdbu, file = NULL)

Value

A string, file name.

Arguments

sdbu

A star_database_update object.

file

A string, file name.

See Also

star_database

Other star database refresh functions: get_existing_fact_instances(), get_lookup_tables(), get_new_dimension_instances(), get_star_database(), get_star_schema(), get_transformation_code(), incremental_refresh(), update_according_to()

Examples

Run this code

f1 <- flat_table('ft_num', ft_cause_rpd) |>
  as_star_database(mrs_cause_schema_rpd) |>
  replace_attribute_values(
    name = "When Available",
    old = c('1962', '11', '1962-03-14'),
    new = c('1962', '3', '1962-01-15')
  ) |>
  group_dimension_instances(name = "When")
f2 <- flat_table('ft_num2', ft_cause_rpd) |>
  update_according_to(f1)
file <- f2 |>
  get_transformation_file()

Run the code above in your browser using DataLab