Learn R Programming

rolap (version 2.5.1)

group_by_keys: Group table instances by keys aggregating the measures using the corresponding aggregation function.

Description

Group table instances by keys aggregating the measures using the corresponding aggregation function.

Usage

group_by_keys(table, keys, measures, agg_functions, nrow_agg)

Value

A tibble.

Arguments

table

A tibble, the instances table.

keys

A vector of strings, key names to group by.

measures

A vector of strings, measures to aggregate.

agg_functions

A vector of strings, aggregate functions.

nrow_agg

A string, name of a new column to count the number of rows aggregated.