Learn R Programming

rolap (version 2.5.1)

group_dimension_instances: Group instances of a dimension

Description

After changes in values in the instances of a dimension, groups the instances and, if necessary, also the related facts.

Usage

group_dimension_instances(db, name)

# S3 method for star_database group_dimension_instances(db, name)

Value

A star_database object.

Arguments

db

A star_database object.

name

A string, dimension name.

See Also

star_schema, flat_table

Other star database definition functions: get_dimension_names(), get_dimension_table(), get_fact_names(), get_role_playing_dimension_names(), get_table_names(), role_playing_dimension(), star_database()

Examples

Run this code

db <- star_database(mrs_cause_schema, ft_num) |>
  group_dimension_instances(name = "where")

Run the code above in your browser using DataLab