Learn R Programming

rolap (version 2.5.1)

unify_rpd: Unify lists of dimension names if there are any in common

Description

Unify lists of dimension names if there are any in common

Usage

unify_rpd(rpd)

Value

A list of strings (dimension names).

Arguments

rpd

A list of strings (dimension names).