From a star_database with at least one geoattribute, we obtain a geolayer
object that allows us to select the data to obtain a vector layer with
geographic information.
If only one geographic attribute is defined, it is not necessary to indicate
the dimension or the attribute. By default, polygon geometry is considered.