get_all_dimension_operations: Gets the operations performed on a dimension in all star_database objects
Description
Gets the operations performed on a dimension in all star_database objects
Usage
get_all_dimension_operations(op_name, name, stars)
Value
A star_operations object.
Arguments
- op_name
A string, operation name.
- name
A string, element name.
- stars
A list of star_database objects.