Learn R Programming

rolap (version 2.5.1)

get_fact_names: Get the names of the facts of a star database

Description

Obtain the names of the facts of a star database.

Usage

get_fact_names(db)

# S3 method for star_database get_fact_names(db)

Value

A vector of strings, fact names.

Arguments

db

A star_database object.

See Also

star_schema, flat_table

Other star database definition functions: get_dimension_names(), get_dimension_table(), get_role_playing_dimension_names(), get_table_names(), group_dimension_instances(), role_playing_dimension(), star_database()

Examples

Run this code

names <- star_database(mrs_cause_schema, ft_num) |>
  get_fact_names()

Run the code above in your browser using DataLab