Learn R Programming

rolap (version 2.5.1)

get_new_dimension_instances: Get new dimension instances

Description

From the planned update, it obtains the instances of the update dimensions that are not included in the star database dimensions to be updated.

Usage

get_new_dimension_instances(sdbu)

# S3 method for star_database_update get_new_dimension_instances(sdbu)

Value

A list of tibble objects.

Arguments

sdbu

A star_database_update object.

See Also

star_database

Other star database refresh functions: get_existing_fact_instances(), get_lookup_tables(), get_star_database(), get_star_schema(), get_transformation_code(), get_transformation_file(), incremental_refresh(), update_according_to()

Examples

Run this code

f1 <-
  flat_table('ft_num', ft_cause_rpd[ft_cause_rpd$City != 'Cambridge' &
                                      ft_cause_rpd$WEEK != '4',]) |>
  as_star_database(mrs_cause_schema_rpd) |>
  role_playing_dimension(rpd = "When",
                         roles = c("When Available", "When Received"))
f2 <- flat_table('ft_num2', ft_cause_rpd[ft_cause_rpd$City != 'Bridgeport' &
                                           ft_cause_rpd$WEEK != '2',])
f2 <- f2 |>
  update_according_to(f1)
dim_instances <- f2 |>
  get_new_dimension_instances()

Run the code above in your browser using DataLab