Group table instances by keys aggregating the measures using the corresponding aggregation function.
group_by_keys(table, keys, measures, agg_functions, nrow_agg)A tibble.
A tibble, the instances table.
A vector of strings, key names to group by.
A vector of strings, measures to aggregate.
A vector of strings, aggregate functions.
A string, name of a new column to count the number of rows aggregated.