powered by
After changes in values in the instances of a dimension, groups the instances and, if necessary, also the related facts.
group_dimension_instances(db, name)# S3 method for star_database group_dimension_instances(db, name)
# S3 method for star_database group_dimension_instances(db, name)
A star_database object.
star_database
A string, dimension name.
star_schema, flat_table
star_schema
flat_table
Other star database definition functions: get_dimension_names(), get_dimension_table(), get_fact_names(), get_role_playing_dimension_names(), get_table_names(), role_playing_dimension(), star_database()
get_dimension_names()
get_dimension_table()
get_fact_names()
get_role_playing_dimension_names()
get_table_names()
role_playing_dimension()
star_database()
db <- star_database(mrs_cause_schema, ft_num) |> group_dimension_instances(name = "where")
Run the code above in your browser using DataLab